@@ -3,8 +3,9 @@ import os
 import json
 from dataclasses import asdict
 from mw_python_sdk import download_file, get_dataset, delete_file
+import logging
 
-
+logging.basicConfig(level=logging.DEBUG)
 class TestDeleteFile(unittest.TestCase):
     def test_download(self):
         dataset_id_tmp = "66b08ec9898e74a8232bb2d1"
